# Table of contents

* [Welcome to EthHub](README.md)

## Ethereum 101

* [What is Ethereum?](ethereum-101/what-is-ethereum.md)
* [Ethereum Use Cases](ethereum-101/ethereum-use-cases/README.md)
  * [Open Finance](ethereum-101/ethereum-use-cases/open-finance.md)
  * [Ether as Money](ethereum-101/ethereum-use-cases/ether-as-money.md)
  * [Store of Value](ethereum-101/ethereum-use-cases/store-of-value.md)
* [Key Concepts](ethereum-101/key-concepts/README.md)
  * [Gas](ethereum-101/key-concepts/gas.md)
  * [Fee Market](ethereum-101/key-concepts/fee-market.md)
  * [Smart Contracts](ethereum-101/key-concepts/smart-contracts.md)
  * [Solidity](ethereum-101/key-concepts/solidity.md)
* [History](ethereum-101/history/README.md)
  * [Pre-Mainnet](ethereum-101/history/pre-mainnet.md)
  * [Hard Forks](ethereum-101/history/hard-forks.md)
  * [The DAO and Ethereum Classic](ethereum-101/history/the-dao-and-ethereum-classic.md)
  * [DDOS Attacks](ethereum-101/history/ddos-attacks.md)
* [Monetary Policy](ethereum-101/monetary-policy/README.md)
  * [Economic Abstraction](ethereum-101/monetary-policy/economic-abstraction.md)
* [Governance](ethereum-101/governance.md)

## Roadmap

* [Timeline](roadmap/timeline.md)
* [Scaling](roadmap/layer-1-scaling/README.md)
  * [Layer 1](roadmap/layer-1-scaling/sharding/README.md)
    * [Sharding](roadmap/layer-1-scaling/sharding/sharding.md)
  * [Layer 2](roadmap/layer-1-scaling/layer-2/README.md)
    * [Plasma](roadmap/layer-1-scaling/layer-2/plasma.md)
    * [State Channels](roadmap/layer-1-scaling/layer-2/state-channels.md)
* [Proof of Stake](roadmap/layer-2-scaling/README.md)
  * [Benefits of PoS](roadmap/layer-2-scaling/plasma.md)
  * [Transition from PoW](roadmap/layer-2-scaling/state-channels.md)
  * [Staking](roadmap/layer-2-scaling/staking.md)
* [Privacy](roadmap/privacy.md)

## Using Ethereum

* [Running a Node](using-ethereum/running-a-node/README.md)
  * [Geth](using-ethereum/running-a-node/geth.md)
  * [Parity](using-ethereum/running-a-node/parity.md)
* [Wallets](using-ethereum/wallets/README.md)
  * [Software](using-ethereum/wallets/desktop.md)
  * [Hardware](using-ethereum/wallets/mobile.md)
  * [Custody](using-ethereum/wallets/hardware.md)
* [Interacting with Web3](using-ethereum/interacting-with-web3.md)
* [Transactions](using-ethereum/transacting.md)
* [Essential Tools](using-ethereum/essential-tools.md)

## Tokens

* [ERC Token Standards](tokens/what-is-erc/README.md)
  * [ERC20](tokens/what-is-erc/erc20.md)
  * [ERC721](tokens/what-is-erc/erc721.md)
* [TCRs](tokens/tcrs.md)
* [NFTs](tokens/nfts.md)

## Ethereum Myths

* [\*\*TEMPLATE FOR MYTHS\*\*](ethereum-myths/template.md)
* [Is Ethereum centralized?](ethereum-myths/is-ethereum-centralized.md)
* [Is Ethereum more expensive to use when the Ether price is higher?](ethereum-myths/centralization-myth.md)
* [I heard that Ethereum will never scale so how will it support all these dapps?](ethereum-myths/cost-myth.md)
* [If it cost money to send a transaction on Ethereum, how will it compete with free blockchains?](ethereum-myths/if-ethereum-is-not-free-to-use-how-will-it-ever-compete-with-blockchains-that-provide-free-trans.md)
* [Is Ethereum Classic the original Ethereum?](ethereum-myths/is-ethereum-classic-is-the-original-ethereum.md)
* [Is Ethereum a Store of Value?](ethereum-myths/is-ethereum-a-store-of-value.md)
* [If Ether has an infinite supply how can we expect Ether to ever hold value?](ethereum-myths/if-ether-has-an-infinite-supply-how-can-we-expect-ether-to-ever-hold-value.md)
* [Is Ethereum a security?](ethereum-myths/is-ethereum-a-security.md)
* [Is Ethereum only good for scam ICOs?](ethereum-myths/is-ethereum-only-good-for-scam-icos.md)
* [Is Ethereum Immutable?](ethereum-myths/is-ethereum-immutable.md)

## Built on Ethereum

* [\*\*TEMPLATE FOR DAPPS\*\*](built-on-ethereum/template-for-dapps.md)
* [Decentralized Exchanges](built-on-ethereum/decentralized-exchanges/README.md)
  * [0x Protocol](built-on-ethereum/decentralized-exchanges/0x-protocol/README.md)
    * [0x Relayers](built-on-ethereum/decentralized-exchanges/0x-protocol/0x-relayers.md)
  * [AirSwap](built-on-ethereum/decentralized-exchanges/airswap.md)
  * [Kyber](built-on-ethereum/decentralized-exchanges/kyber.md)
  * [Totle](built-on-ethereum/decentralized-exchanges/totle.md)
* [Open Finance](built-on-ethereum/open-finance/README.md)
  * [Stablecoins](built-on-ethereum/open-finance/stablecoins/README.md)
    * [Dai](built-on-ethereum/open-finance/stablecoins/dai.md)
    * [GUSD](built-on-ethereum/open-finance/stablecoins/gusd.md)
  * [Lending](built-on-ethereum/open-finance/lending/README.md)
    * [dYdX](built-on-ethereum/open-finance/lending/dydx/README.md)
      * [expo](built-on-ethereum/open-finance/lending/dydx/expo.md)
    * [Dharma](built-on-ethereum/open-finance/lending/dharma.md)
    * [Compound](built-on-ethereum/open-finance/lending/compound.md)
  * [Set Protocol](built-on-ethereum/open-finance/set-protocol.md)
  * [Digix](built-on-ethereum/open-finance/digix.md)
* [Marketplaces](built-on-ethereum/marketplaces/README.md)
  * [OpenSea](built-on-ethereum/marketplaces/opensea.md)
  * [RareBits](built-on-ethereum/marketplaces/rarebits.md)
* [Games](built-on-ethereum/games/README.md)
  * [God's Unchained](built-on-ethereum/games/gods-unchained.md)
  * [Zombie Battlegrounds](built-on-ethereum/games/zombie-battlegrounds.md)
  * [CryptoKitties](built-on-ethereum/games/cryptokitties.md)
* [Collectibles](built-on-ethereum/collectables/README.md)
  * [CryptoPunks](built-on-ethereum/collectables/cryptopunks.md)
  * [MLB Crypto Baseball](built-on-ethereum/collectables/mlb-crypto-baseball.md)
* [Prediction Markets](built-on-ethereum/prediction-markets/README.md)
  * [Augur](built-on-ethereum/prediction-markets/augur.md)
  * [Gnosis](built-on-ethereum/prediction-markets/gnosis.md)
* [Identity](built-on-ethereum/identity.md)
* [Governance](built-on-ethereum/governance.md)

